package com.muyu.controller;

import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.domain.EngineType;
import com.muyu.domain.constants.Result;
import com.muyu.service.TypeService;
import jakarta.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;


/**
 * @Author：qdm
 * @Package：com.muyu.controller
 * @Project：cloud-etl-engine
 * @name：TypeController
 * @Date：2024/8/23 22:35
 */
@RestController
@RequestMapping("/type")
public class TypeController extends BaseController {
    @Autowired
    TypeService typeService;

    /**
     * 类型列表
     *
     * @return
     */
    @PostMapping("/list")
    public List<EngineType> list() {
        //使用mybatis-plus 查询所有
        //return Result.success(typeService.list());
        return typeService.list();
    }

    /**
     * 类型添加
     *
     * @param type
     * @return
     */
    @PostMapping("/add")
    public Result add(@RequestBody EngineType type) {
        //使用mybatis-plus 添加
//        typeService.add(type);
        return typeService.add(type);
    }

    /**
     * 修改类型
     *
     * @param type
     * @return
     */
    @PostMapping("/update")
    public Result upadte(@RequestBody EngineType type) {
        //使用mybatis-plus 修改
//        return typeService.update(type);
        return typeService.update(type);
    }

    /**
     * 删除类型
     *
     * @param id
     * @return
     */
    @PostMapping("/delete/{id}")
    public Result delete(@PathVariable Integer id) {
        //使用mybatis-plus 删除
//        boolean b = typeService.removeById(id);
        return typeService.delete(id);
    }

    /**
     * 导出
     */
    @PostMapping("/export")
    public void export(HttpServletResponse httpServletResponse, EngineType type) {
        List<EngineType> list = typeService.list();
        ExcelUtil<EngineType> engineMaintenanceExcelUtil = new ExcelUtil<>(EngineType.class);
        engineMaintenanceExcelUtil.exportExcel(httpServletResponse, list, "规则引擎版本");
    }
}
